@@ -21,6 +21,7 @@
 #include <QAction>
 #include <QDesktopServices>
 #include <QFileDialog>
+#include <QFontDatabase>
 #include <QFormLayout>
 #include <QGroupBox>
 #include <QLabel>
@@ -60,20 +61,21 @@ public:
     QAction *saveAttachmentAction = nullptr;
     QAction *openAttachmentAction = nullptr;
     QAction *importPublicKeyAction = nullptr;
+    bool fixedFont = false;
 
     void createActions()
     {
-        saveAttachmentAction = new QAction(QIcon::fromTheme(QStringLiteral("document-save-as")), i18n("&Save Attachment As…"), q);
+        saveAttachmentAction = new QAction(QIcon::fromTheme(QStringLiteral("document-save-as-symbolic")), i18n("&Save Attachment As…"), q);
         connect(saveAttachmentAction, &QAction::triggered, q, [this]() {
             saveSelectedAttachments();
         });
 
-        openAttachmentAction = new QAction(i18nc("to open", "Open"), q);
+        openAttachmentAction = new QAction(QIcon::fromTheme(QStringLiteral("document-open-symbolic")), i18nc("to open", "Open"), q);
         connect(openAttachmentAction, &QAction::triggered, q, [this]() {
             openSelectedAttachments();
         });
 
-        importPublicKeyAction = new QAction(i18nc("@action:inmenu", "Import public key"), q);
+        importPublicKeyAction = new QAction(QIcon::fromTheme(QStringLiteral("document-import-key-symbolic")), i18nc("@action:inmenu", "Import public key"), q);
         connect(importPublicKeyAction, &QAction::triggered, q, [this]() {
             importPublicKey();
         });
@@ -245,6 +247,9 @@ void MessageViewer::Private::recursiveBuildViewer(PartModel *parts, QVBoxLayout
             label->setTextInteractionFlags(Qt::TextBrowserInteraction);
             label->setOpenExternalLinks(true);
             label->setWordWrap(true);
+            if (fixedFont) {
+                label->setFont(QFontDatabase::systemFont(QFontDatabase::FixedFont));
+            }
             container->layout()->addWidget(label);
             layout->addWidget(container);
             break;
@@ -400,7 +405,7 @@ void MessageViewer::setMessage(const KMime::Message::Ptr message)
         d->formLayout->addRow(i18n("&BCC:"), new HeaderLabel(d->parser.bcc()));
     }
     if (!d->parser.date().isNull()) {
-        d->formLayout->addRow(i18n("&Date:"), new HeaderLabel(QLocale::system().toString(d->parser.date().toLocalTime())));
+        d->formLayout->addRow(i18n("&Date:"), new HeaderLabel(QLocale::system().toString(d->parser.date().toLocalTime(), QLocale::ShortFormat)));
     }
 
     const auto parts = d->parser.parts();
@@ -439,3 +444,15 @@ void MessageViewer::print(QPainter *painter, int width)
     d->scrollArea->setFrameShape(QFrame::StyledPanel);
     resize(oldSize);
 }
+
+bool MessageViewer::fixedFont() const
+{
+    return d->fixedFont;
+}
+
+void MessageViewer::setFixedFont(bool checked)
+{
+    d->fixedFont = checked;
+
+    setMessage(message()); // rebuild UI
+}
